# ZLMDB high level API tests

* [test_zdb_df.py](test_zdb_df.py): test pandas dataframe integration
* [test_zdb_etcd.py](test_zdb_etcd.py): test etcd data integration
* [test_zdb_dyn.py](test_zdb_dyn.py): test self describing database format

## Notes

```console
signify -S -s key.sec -m message.txt -x msg.sig
```
